==> segatex-8.600.tar.gz: segatex-8.600/src/segatex_yum_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXYUMPROCESS_H
#define SEGATEXYUMPROCESS_H

#include <QProcess> 
#include <QVBoxLayout> 
#include <QHBoxLayout> 

#include "segatex_yum.h" 


class SegatexYumProcess: public QDialog 
{
	Q_OBJECT
public:
	SegatexYumProcess(QWidget *parent = 0, const char *name = 0);
    
public slots:
signals:
	void yum_prosess_close_button_clicked();
protected:

private slots:
	void close_button_clicked();
	void yum_install_base_process();
	void yum_update_base_process();
	void readFromStdout();
	void updateOutputTextEdit();
        void processExited(int, QProcess::ExitStatus);
	void updateOutputTextEdit1();
	void readFromStdout1();
        void processExited1(int, QProcess::ExitStatus);
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QProcess *process;
	QProcess *process1;
	QVBoxLayout *headLayout;
	QHBoxLayout *footLayout;
	QVBoxLayout *mainLayout;
	SegatexYum *selinux_yum_on;
	SegatexYumProcess *selinux_yum_process;
	SegatexYumProcess *selinux_yum_process_progress;
	int a,b,c;
};

#endif

==> segatex-8.630.tar.gz: segatex-8.630/src/segatex_yum_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXYUMPROCESS_H
#define SEGATEXYUMPROCESS_H

#include <QProcess> 
#include <QVBoxLayout> 
#include <QHBoxLayout> 

#include "segatex_yum.h" 


class SegatexYumProcess: public QDialog 
{
	Q_OBJECT
public:
	SegatexYumProcess(QWidget *parent = 0, const char *name = 0);
    
public slots:
signals:
	void yum_process_close_button_clicked();
protected:

private slots:
	void close_button_clicked();
	void yum_install_base_process();
	void yum_update_base_process();
	void readFromStdout();
	void updateOutputTextEdit();
        void processExited(int, QProcess::ExitStatus);
	void updateOutputTextEdit1();
	void readFromStdout1();
        void processExited1(int, QProcess::ExitStatus);
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QProcess *process;
	QProcess *process1;
	QVBoxLayout *headLayout;
	QHBoxLayout *footLayout;
	QVBoxLayout *mainLayout;
	SegatexYum *selinux_yum_on;
	SegatexYumProcess *selinux_yum_process;
	SegatexYumProcess *selinux_yum_process_progress;
	int a,b,c;
};

#endif
